Name:           verilator
Version:        5.032
Release:        1%{?dist}
Summary:        A fast simulator for synthesizable Verilog
License:        LGPL-3.0-only AND Artistic-2.0 AND CC0-1.0 AND MIT
URL:            https://www.veripool.com/%{name}.html
Source0:        https://github.com/%{name}/%{name}/archive/refs/tags/v%{version}.tar.gz
 
BuildRequires:  bison coreutils findutils flex
BuildRequires:  autoconf gcc-c++ make help2man
BuildRequires:  python3
# for testing
BuildRequires:  perl-FindBin perl-version perl-lib perl-Time-HiRes

%description
Verilator is the fastest free Verilog HDL simulator. It compiles
synthesizable Verilog, plus some PSL, SystemVerilog and Synthesis
assertions into C++ or SystemC code. It is designed for large projects
where fast simulation performance is of primary concern, and is
especially well suited to create executable models of CPUs for
embedded software design teams.

%package devel
Summary: Development files for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
Development files for %{name}


%package doc
Summary: Documentation and example files for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}
Buildarch: noarch

%description doc
Documentation and example files for %{name}

export VERILATOR_ROOT=%{_datadir}

%prep

%setup -q
find . -name .gitignore -delete
autoconf

%{configure} \
    --disable-ccwarn \
    --enable-defenv \
    --disable-longtests
# We cannot run autoreconf because upstream uses unqualifed stdlib identifiers
# that are included by autoconf-generated header files.
find -name Makefile_obj -exec sed -i \
    -e 's|^\(COPT = .*\)|\1 %{optflags}|' \
    -e 's|^#LDFLAGS += .*|LDFLAGS += %{__global_ldflags}|' \
    {} \;

%build
%make_build

%check
make test

rm -rf  examples/make_{hello_{binary,c},protect_lib,tracing_c}/obj_dir/{Vtop{,__*},*.a,*.o}
rm -rf  examples/make_protect_lib/obj_dir_secret/*.{a,o,so}
%install
%make_install

# generate missing man pages
for app in %{name}_{bin,bin_dbg,coverage_bin_dbg}; do
    help2man --no-discard-stderr "%{buildroot}%{_bindir}/$app" \
    --version-option=version --output=%{buildroot}%{_mandir}/man1/$app.1
done

# remove the copy of examples in the datadir so we could
# mark the copy in the source directory as "doc"
rm -rf %{buildroot}%{_datadir}/%{name}/examples

# remove not needed build directory and bin directory
rm -rf %{buildroot}%{_datadir}/%{name}/src
rm -rf %{buildroot}%{_bindir}/%{name}_includer

# verilator installs verilator.pc under ${datadir}
# but for consistency we want it under ${libdir}
mkdir -p %{buildroot}%{_libdir}/pkgconfig
mv %{buildroot}%{_datadir}/pkgconfig/%{name}.pc %{buildroot}%{_libdir}/pkgconfig

# for py in vl_file_copy vl_hier_graph; do
#     sed -i -e 's#/usr/bin/env python3#%%{python3}#g' examples/xml_py/$py 
# done 

%files
%{_bindir}/%{name}*
%license Artistic LICENSE
%doc Changes README*
#%%doc verilator.pdf verilator.html

%{_mandir}/man1/%{name}*.1.gz
%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/include/


%files devel
%license Artistic LICENSE
%doc Changes README*
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/include/
#%%{_docdir}/%%{name}-doc/examples/make_tracing_c/obj_dir/*.h


#examples/make_protect_lib/obj_dir_secret/Vsecret_impl*.h
# %%doc examples/make_{hello_{binary,c},protect_lib,tracing_c}/obj_dir{,_secret}/*.h
#%%{_docdir}/verilator-devel/Vtop.h

%files doc

#%%exclude %%doc examples/make_protect_lib/obj_dir_secret/Vsecret_impl*.h
#%%exclude %%doc examples/make_{hello_{binary,c},protect_lib,tracing_c}/obj_dir{,_secret}/*.h
#%%doc examples/
#%%exclude %%{_docdir}/%%{name}-doc/examples/make_tracing_c/obj_dir/*.h

#%%exclude %%{_docdir}/verilator-devel/Vtop.h

%changelog
* Fri Jan 3 2025 Pappy Packager <skrochen@krotek.com> - 5.032-1
- Update to 5.032

* Sun Oct 27 2024 Pappy Packager <skrochen@krotek.com> - 5.030-1
- Update to 5.030

* Sun Sep 01 2024 Pappy Packager <skrochen@krotek.com> - 5.028-1
- Update to 5.028

* Tue Apr 16 2024 Pappy Packager <skrochen@krotek.com> - 5.024-5
- Update to 5.024

* Sun Mar 17 2024 Pappy Packager <skrochen@krotek.com> - 5.022-4
- Update to 5.022 and Fedora 39

* Thu Nov 02 2023 Pappy Packager <skrochen@krotek.com> - 5.018-3
- Update to 5.018 and Fedora 38

* Fri Mar 17 2023 Pappy Packager <skrochen@krotek.com> - 4.226-1
- Update to 4.226 and Fedora 37

* Fri Sep 23 2022 Pappy Packager <skrochen@krotek.com> - 4.226-1
- Update to 4.226 and Fedora 36

* Fri Feb 11 2022 Pappy Packager <skrochen@krotek.com> - 4.216-1
- Update to 4.216
- Escape macros in %%changelog and comments

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.108-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.108-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Mon Jan 25 2021 Filipe Rosset <rosset.filipe@gmail.com> - 4.108-1
- Update to 4.108 fixes rhbz#1901487

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.032-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Fri Apr 24 2020 Filipe Rosset <rosset.filipe@gmail.com> - 4.032-1
- Update to 4.032

* Sun Feb 16 2020 Filipe Rosset <rosset.filipe@gmail.com> - 4.028-1
- Update to 4.028

* Fri Jan 31 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.026-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Wed Jan 22 2020 Filipe Rosset <rosset.filipe@gmail.com> - 4.026-1
- Update to 4.026 fixes rhbz#1747211

* Thu Aug 22 2019 Filipe Rosset <rosset.filipe@gmail.com> - 4.016-1
- Updated to 4.016 fixes rhbz#1590822 rhbz#1643479 and rhbz#1700228

* Sat Jul 27 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.922-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri May 03 2019 Scott Tsai scottt.tw@gmail.com - 3.922-5
- Remove duplicate copies of 'examples' in /usr/share/doc
- https://bugzilla.redhat.com/show_bug.cgi?id=1592057#c3

* Fri May 03 2019 Marcus Müller <marcus@hostalia.de> - 3.922-4
- Made %%{_bindir}/verilator et al executable, fixes rhbz #1592057

* Sun Feb 03 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.922-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.922-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sun Mar 18 2018 Filipe Rosset <rosset.filipe@gmail.com> - 3.922-1
- 3.922 bump, fixes rhbz #1557720

* Fri Feb 09 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3.920-2
- Escape macros in %%changelog

* Wed Feb 07 2018 Filipe Rosset <rosset.filipe@gmail.com> - 3.920-1
- 3.920 bump
- Disabled tests until upstream fixes the issue
- Added BR to fix EPEL7 build
- Fixes rhbz #1250122 and rhbz #1494887

* Fri Sep 08 2017 Petr Pisar <ppisar@redhat.com> - 3.910-1
- 3.910 bump
- License corrected to (LGPLv3 or Artistic 2.0)

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.890-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.890-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.890-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.890-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Nov 28 2016 Filipe Rosset <rosset.filipe@gmail.com> - 3.890-2
- Attempt to rebuilt on rawhide due dependency problems

* Mon Nov 28 2016 Filipe Rosset <rosset.filipe@gmail.com> - 3.890-1
- Rebuilt for new upstream version 3.890
- Spec clean up plus fixes rhbz #1087393 and rhbz #1358609

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.874-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.874-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Jun 07 2015 Scott Tsai <scottt.tw@gmail.com> - 3.874-1
- Upstream 3.874

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 3.864-2
- Rebuilt for GCC 5 C++11 ABI change

* Mon Sep 22 2014 Scott Tsai <scottt.tw@gmail.com> 3.864-1
- Upstream 3.864

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.862-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jun 13 2014 Scott Tsai <scottt.tw@gmail.com> 3.862-1
- Upstream 3.862
